.. tdm_loader documentation master file, created by
   sphinx-quickstart on Fri Feb 10 15:00:17 2017.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

tdm_loader
======================================

Contents:

.. toctree::
   :maxdepth: 2

.. autoclass:: tdm_loader.tdm_loader.OpenFile
   :members:

Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`

